@@ -74,7 +74,7 @@ static void launch_selected_app (AppShellData * app_data);
 static void generate_potential_apps (gpointer catdata, gpointer user_data);
 
 static void relayout_shell (AppShellData * app_data);
-static gboolean handle_filter_changed (NldSearchBar * search_bar, int context, const char *text,
+static gboolean handle_filter_changed (NldSearchBar * search_bar, const char *text,
 	gpointer user_data);
 static void handle_group_clicked (Tile * tile, TileEvent * event, gpointer user_data);
 static void set_state (AppShellData * app_data, GtkWidget * widget);
@@ -581,7 +581,7 @@ handle_filter_changed_delayed (gpointer user_data)
 }
 
 static gboolean
-handle_filter_changed (NldSearchBar * search_bar, int context, const char *text, gpointer data)
+handle_filter_changed (NldSearchBar * search_bar, const char *text, gpointer data)
 {
 	AppShellData *app_data;
 
@@ -871,50 +871,53 @@ void
 generate_categories (AppShellData * app_data)
 {
 	MateMenuTreeDirectory *root_dir;
-	GSList *contents, *l;
 	gboolean need_misc = FALSE;
+	MateMenuTreeIter *iter;
+	MateMenuTreeItemType type;
 
 	if (!app_data->tree)
 	{
-		app_data->tree = matemenu_tree_lookup (app_data->menu_name, MATEMENU_TREE_FLAGS_NONE);
-		matemenu_tree_add_monitor (app_data->tree, matemenu_tree_changed_callback, app_data);
+		GError *error = NULL;
+
+		app_data->tree = matemenu_tree_new (app_data->menu_name, MATEMENU_TREE_FLAGS_NONE);
+		g_signal_connect (app_data->tree, "changed", G_CALLBACK (matemenu_tree_changed_callback), app_data);
+		if (! matemenu_tree_load_sync (app_data->tree, &error)) {
+			g_warning("Menu tree loading got error:%s\n", error->message);
+			g_error_free(error);
+			g_object_unref(app_data->tree);
+			app_data->tree = NULL;
+		}
+
 	}
-	root_dir = matemenu_tree_get_root_directory (app_data->tree);
-	if (root_dir)
-		contents = matemenu_tree_directory_get_contents (root_dir);
-	else
-		contents = NULL;
-	if (!root_dir || !contents)
-	{
+
+	if ((root_dir = matemenu_tree_get_root_directory (app_data->tree)) == NULL ) {
 		GtkWidget *dialog = gtk_message_dialog_new (NULL, GTK_DIALOG_DESTROY_WITH_PARENT,
-			GTK_MESSAGE_ERROR, GTK_BUTTONS_CLOSE, "Failure loading - %s",
-			app_data->menu_name);
+				GTK_MESSAGE_ERROR, GTK_BUTTONS_CLOSE, "Failure loading - %s",
+				app_data->menu_name);
 		gtk_dialog_run (GTK_DIALOG (dialog));
 		gtk_widget_destroy (dialog);
 		exit (1);	/* Fixme - is there a MATE/GTK way to do this. */
 	}
 
-	for (l = contents; l; l = l->next)
-	{
+	iter = matemenu_tree_directory_iter (root_dir);
+	while ((type = matemenu_tree_iter_next (iter)) != MATEMENU_TREE_ITEM_INVALID) {
+		gpointer item;
 		const char *category;
-		MateMenuTreeItem *item = l->data;
-
-		switch (matemenu_tree_item_get_type (item))
-		{
-		case MATEMENU_TREE_ITEM_DIRECTORY:
-			category = matemenu_tree_directory_get_name ((MateMenuTreeDirectory*)item);
-			generate_category(category, (MateMenuTreeDirectory*)item, app_data, TRUE);
-			break;
-		case MATEMENU_TREE_ITEM_ENTRY:
-			need_misc = TRUE;
-			break;
-		default:
-			break;
+		switch (type) {
+			case MATEMENU_TREE_ITEM_DIRECTORY:
+				item = matemenu_tree_iter_get_directory (iter);
+				category = matemenu_tree_directory_get_name (item);
+				generate_category(category, item, app_data, TRUE);
+				matemenu_tree_item_unref (item);
+				break;
+			case MATEMENU_TREE_ITEM_ENTRY:
+				need_misc = TRUE;
+				break;
+			default:
+				break;
 		}
-
-		matemenu_tree_item_unref (item);
 	}
-	g_slist_free (contents);
+	matemenu_tree_iter_unref(iter);
 
 	if (need_misc)
 		generate_category (_("Other"), root_dir, app_data, FALSE);
@@ -1022,52 +1025,54 @@ generate_launchers (MateMenuTreeDirectory * root_dir, AppShellData * app_data, C
 {
 	MateDesktopItem *desktop_item;
 	const gchar *desktop_file;
-	GSList *contents, *l;
+	MateMenuTreeIter *iter;
+	MateMenuTreeItemType type;
 
-	contents = matemenu_tree_directory_get_contents (root_dir);
-	for (l = contents; l; l = l->next)
-	{
-		switch (matemenu_tree_item_get_type (l->data))
-		{
-		case MATEMENU_TREE_ITEM_DIRECTORY:
-			/* g_message ("Found sub-category %s", matemenu_tree_directory_get_name (l->data)); */
-			if (recursive)
-				generate_launchers (l->data, app_data, cat_data, TRUE);
-			break;
-		case MATEMENU_TREE_ITEM_ENTRY:
-			/* g_message ("Found item name is:%s", matemenu_tree_entry_get_name (l->data)); */
-			desktop_file = matemenu_tree_entry_get_desktop_file_path (l->data);
-			if (desktop_file)
-			{
-				if (g_hash_table_lookup (app_data->hash, desktop_file))
+	iter = matemenu_tree_directory_iter (root_dir);
+	while ((type = matemenu_tree_iter_next (iter)) != MATEMENU_TREE_ITEM_INVALID) {
+		gpointer item;
+		switch (type) {
+			case MATEMENU_TREE_ITEM_DIRECTORY:
+				item = matemenu_tree_iter_get_directory(iter);
+				/* g_message ("Found sub-category %s", matemenu_tree_directory_get_name (item)); */
+				if (recursive)
+					generate_launchers (item, app_data, cat_data, TRUE);
+				matemenu_tree_item_unref (item);
+				break;
+			case MATEMENU_TREE_ITEM_ENTRY:
+				item = matemenu_tree_iter_get_entry(iter);
+				/* g_message ("Found item name is:%s", matemenu_tree_entry_get_desktop_file_id(item)); */
+				desktop_file = matemenu_tree_entry_get_desktop_file_path (item);
+				if (desktop_file)
 				{
-					break;	/* duplicate */
+					if (g_hash_table_lookup (app_data->hash, desktop_file))
+					{
+						break;	/* duplicate */
+					}
+					/* Fixme - make sure it's safe to store this without duping it. As far as I can tell it is
+					   safe as long as I don't hang on to this anylonger than I hang on to the MateMenuTreeEntry*
+					   which brings up another point - am I supposed to free these or does freeing the top level recurse
+					   */
+					g_hash_table_insert (app_data->hash, (gpointer) desktop_file,
+							(gpointer) desktop_file);
 				}
-				/* Fixme - make sure it's safe to store this without duping it. As far as I can tell it is
-				   safe as long as I don't hang on to this anylonger than I hang on to the MateMenuTreeEntry*
-				   which brings up another point - am I supposed to free these or does freeing the top level recurse
-				*/
-				g_hash_table_insert (app_data->hash, (gpointer) desktop_file,
-					(gpointer) desktop_file);
-			}
-			desktop_item = mate_desktop_item_new_from_file (desktop_file, 0, NULL);
-			if (!desktop_item)
-			{
-				g_critical ("Failure - mate_desktop_item_new_from_file(%s)",
-					    desktop_file);
+				desktop_item = mate_desktop_item_new_from_file (desktop_file, 0, NULL);
+				if (!desktop_item)
+				{
+					g_critical ("Failure - mate_desktop_item_new_from_file(%s)",
+							desktop_file);
+					break;
+				}
+				if (!check_specific_apps_hack (desktop_item))
+					insert_launcher_into_category (cat_data, desktop_item, app_data);
+				mate_desktop_item_unref (desktop_item);
+				matemenu_tree_item_unref (item);
+				break;
+			default:
 				break;
-			}
-			if (!check_specific_apps_hack (desktop_item))
-				insert_launcher_into_category (cat_data, desktop_item, app_data);
-			mate_desktop_item_unref (desktop_item);
-			break;
-		default:
-			break;
 		}
-
-		matemenu_tree_item_unref (l->data);
 	}
-	g_slist_free (contents);
+	matemenu_tree_iter_unref(iter);
 }
 
 static void
